Package: mlr3fda
Title: Extending 'mlr3' to Functional Data Analysis
Version: 0.6.0
Authors@R: c(
    person("Maximilian", "Mücke", , "muecke.maximilian@gmail.com", role = c("aut", "cre"),
           comment = c(ORCID = "0009-0000-9432-9795")),
    person("Sebastian", "Fischer", , "sebf.fischer@gmail.com", role = "aut",
           comment = c(ORCID = "0000-0002-9609-3197")),
    person("Fabian", "Scheipl", , "fabian.scheipl@googlemail.com", role = "ctb",
           comment = c(ORCID = "0000-0001-8172-3603")),
    person("Bernd", "Bischl", , "bernd_bischl@gmx.net", role = "ctb",
           comment = c(ORCID = "0000-0001-6002-6980"))
  )
Description: Extends the 'mlr3' ecosystem to functional analysis by adding
    support for irregular and regular functional data as defined in the
    'tf' package.  The package provides 'PipeOps' for preprocessing
    functional columns and for extracting scalar features, thereby
    allowing standard machine learning algorithms to be applied
    afterwards. Available operations include simple functional features
    such as the mean or maximum, smoothing, interpolation, flattening, and
    functional 'PCA'.
License: LGPL-3
URL: https://mlr3fda.mlr-org.com, https://github.com/mlr-org/mlr3fda
BugReports: https://github.com/mlr-org/mlr3fda/issues
Depends: mlr3 (>= 1.3.0), mlr3pipelines (>= 0.5.2), R (>= 4.1.0)
Imports: checkmate, data.table (>= 1.18.0), lgr, mlr3misc (>= 0.19.0),
        paradox, R6, tf (>= 0.4.0)
Suggests: FDboost, lme4, mboost, rpart, testthat (>= 3.3.0),
        tsfeatures, wavelets, withr
Config/roxygen2/markdown: TRUE
Config/roxygen2/r6: TRUE
Config/roxygen2/version: 8.0.0
Config/testthat/edition: 3
Encoding: UTF-8
LazyData: true
Collate: 'zzz.R' 'PipeOpFDABsignal.R' 'PipeOpFDACor.R'
        'PipeOpFDADepth.R' 'PipeOpFDADerive.R' 'PipeOpFDAExtract.R'
        'PipeOpFDAFlatten.R' 'PipeOpFDAFourier.R' 'PipeOpFDAInterpol.R'
        'PipeOpFDARandomEffect.R' 'PipeOpFDARegister.R'
        'PipeOpFDAScaleRange.R' 'PipeOpFDASmooth.R'
        'PipeOpFDATsfeatures.R' 'PipeOpFDAWavelets.R' 'PipeOpFDAZoom.R'
        'PipeOpFPCA.R' 'TaskClassif_phoneme.R' 'TaskRegr_dti.R'
        'TaskRegr_fuel.R' 'bibentries.R' 'datasets.R' 'hash_input.R'
NeedsCompilation: no
Packaged: 2026-06-01 10:02:53 UTC; mmuecke
Author: Maximilian Mücke [aut, cre] (ORCID:
    <https://orcid.org/0009-0000-9432-9795>),
  Sebastian Fischer [aut] (ORCID:
    <https://orcid.org/0000-0002-9609-3197>),
  Fabian Scheipl [ctb] (ORCID: <https://orcid.org/0000-0001-8172-3603>),
  Bernd Bischl [ctb] (ORCID: <https://orcid.org/0000-0001-6002-6980>)
Maintainer: Maximilian Mücke <muecke.maximilian@gmail.com>
Repository: CRAN
Date/Publication: 2026-06-01 10:40:02 UTC
Built: R 4.5.2; ; 2026-06-01 13:27:59 UTC; unix
