# Generated by roxygen2: do not edit by hand

S3method(hash_input,tfd_irreg)
S3method(hash_input,tfd_reg)
export(PipeOpFDABsignal)
export(PipeOpFDACor)
export(PipeOpFDADepth)
export(PipeOpFDADerive)
export(PipeOpFDAExtract)
export(PipeOpFDAFlatten)
export(PipeOpFDAFourier)
export(PipeOpFDAInterpol)
export(PipeOpFDARandomEffect)
export(PipeOpFDARegister)
export(PipeOpFDAScaleRange)
export(PipeOpFDASmooth)
export(PipeOpFDATsfeatures)
export(PipeOpFDAWavelets)
export(PipeOpFDAZoom)
export(PipeOpFPCA)
import(R6)
import(checkmate)
import(data.table)
import(mlr3)
import(mlr3misc)
import(mlr3pipelines)
import(paradox)
importFrom(tf,tf_approx_fill_extend)
importFrom(tf,tf_approx_linear)
importFrom(tf,tf_approx_locf)
importFrom(tf,tf_approx_nocb)
importFrom(tf,tf_approx_spline)
importFrom(utils,bibentry)
