#' @importFrom utils bibentry
# nolint start
bibentries = c(
  ferraty2003curves = bibentry(
    "article",
    title = "Curves discrimination: a nonparametric functional approach",
    author = "Ferraty, Fr\xc3\xa9d\xc3\xa9ric and Vieu, Philippe",
    journal = "Computational Statistics & Data Analysis",
    volume = "44",
    number = "1-2",
    pages = "161--173",
    year = "2003",
    publisher = "Elsevier"
  ),
  brockhaus2015functional = bibentry(
    "article",
    title = "The functional linear array model",
    author = "Brockhaus, Sarah and Scheipl, Fabian and Hothorn, Torsten and Greven, Sonja",
    journal = "Statistical Modelling",
    volume = "15",
    number = "3",
    pages = "279--300",
    year = "2015",
    publisher = "SAGE Publications Sage India: New Delhi, India"
  ),
  goldsmith2011penalized = bibentry(
    "article",
    title = "Penalized functional regression",
    author = "Goldsmith, Jeff and Bobb, Jennifer and Crainiceanu, Ciprian M and Caffo, Brian and Reich, Daniel",
    journal = "Journal of Computational and Graphical Statistics",
    volume = "20",
    number = "4",
    pages = "830--851",
    year = "2011",
    publisher = "Taylor & Francis"
  ),
  oppenheim2010discrete = bibentry(
    "book",
    title = "Discrete-Time Signal Processing",
    author = "Oppenheim, Alan V and Schafer, Ronald W",
    year = "2010",
    edition = "3rd",
    publisher = "Pearson",
    isbn = "978-0131988422"
  )
)
# nolint end
