#' The fuel dataset
#'
#' See [mlr_tasks_fuel] for a description of the dataset.
#'
#' @docType data
#' @keywords datasets
#' @name fuel
#' @usage data(fuel)
#' @format A data frame with 129 rows and 4 variables
#' @keywords internal
NULL

#' The phoneme dataset
#'
#' See [mlr_tasks_phoneme] for a description of the dataset.
#'
#' @docType data
#' @keywords datasets
#' @name phoneme
#' @usage data(phoneme)
#' @format A data frame with 250 rows and 2 variables
#' @keywords internal
NULL

#' The dti dataset
#'
#' See [mlr_tasks_dti] for a description of the dataset.
#'
#' @docType data
#' @keywords datasets
#' @name dti
#' @usage data(dti)
#' @format A data frame with 340 rows and 5 variables
#' @keywords internal
NULL
