# PipeOpFDASmooth

    Code
      train_pipeop(po_smooth, list(task1))
    Message
      Using `f = 0.15` as smoother span for `lowess()`.
    Output
      $output
      
      -- <TaskRegr> (129x2): Spectral Data of Fossil Fuels ---------------------------
      * Target: heatan
      * Properties: -
      * Features (1):
        * tfr (1): NIR
      

